Context class

Constructors

Context({required String latin, required int index, required int? previousCode})

Properties

canUseMvs → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
isFinal → bool
no setter
isInitial → bool
no setter
isIsolate → bool
no setter
isJixiye → bool
no setter
isMedial → bool
no setter
isNaima → bool
no setter
isNextMale → bool
no setter
isNextOU → bool
no setter
isPreviousHG → bool
no setter
isPreviousMvs → bool
no setter
isPreviousRoundAnytime → bool
no setter
latin → String
final
location → Location
no setter
nextLetter → String
final
previousCode → int?
final
previousLetter → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

findForeignLetterPrevious(int index) → bool
findMaleLetterFromPrevious(int index) → bool
isConsonant(String letter) → bool
isMaleWord() → bool
needToothU(int index) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited